#!/bin/sh

if [ $# -lt 2 ];  then
	echo "Usage: "
	echo "    $0 texture.png outDir [optional]"
	echo "optional:" 
	echo "    -edge - pre-filter image with edge detector"
	echo "    -refl - optimize reflective symmetry"
	echo "    -rot - optimize rotational symmetry"
	echo "    -tile Gx Gy - tile into Gx x Gy grid"
	exit
fi

Gx=0
Gy=0

outDir=$2

# Edge Filter before processing
edgeFilter="-EnergyFn SymmetrizationType SquaredDistancenFromMean"
edgeFilter=$edgeFilter" -FilterDeform Type sobel Blur 1.5 Window 5"

# Reflection symmetry
reflSymm="-SymmetrySpace Type SinglePointReflective Pow 1 Normalization ImgSpace"
reflSymm=$reflSymm" NormScale none NumAngles 360 NumRadii -1 CoordinateSystem Polar"
reflSymm=$reflSymm" -Optimizer NumDims -2  CenterOfMass [ intensityMass ] -DeformationModel ZoomWindow 1. HierarchyMin 2 HierarchyMax 64"

# Rotational symmetry
rotSymm="-SymmetrySpace Type SinglePointRotational Pow 1 Normalization ImgSpace"
rotSymm=$rotSymm" NormScale none NumAngles 360 NumRadii -1 CoordinateSystem Polar"
rotSymm=$rotSymm" -Optimizer NumDims -2  CenterOfMass [ intensityMass ] -DeformationModel ZoomWindow 1. HierarchyMin 4 HierarchyMax 8"

# Parameters 
params=""
for ((i=3; i<=$#; i++)); do
	echo ${!i}
	if [ ${!i} == "-edge" ]; then
		params="$params $edgeFilter"
	elif [ ${!i} == "-refl" ]; then
		params="$params $reflSymm"
	elif [ ${!i} == "-rot" ]; then
		params="$params $rotSymm"
	elif [ ${!i} == "-tile" ]; then
		let i=i+1;
		Gx=${!i};
		let i=i+1;
		Gy=${!i};
	fi
done

echo "$params"
#addParams="-DeformationModel HierarchyMin 16 HierarchyMax 256 NumCtrl 257 -SymmetrySpace CropSymDims [.6 .6]"		# reptile (global curved)
# $addParams
settings="./symmetrizeImage.txt"
./SymAnalogyImage $1 $settings $outDir $params

cp "progress_f_000000.png" $outDir"/f.png"
gifsicle -d 0 -l ./progress_f*.gif > ./$outDir/anim_f.gif
gifsicle -d 0 -l ./progress_Sf*.gif > ./$outDir/anim_Sf.gif	
rm progress*
rm MeshFeatures.png
rm MeshTriangles.png



# Optional: stich into Gx x Gy grid
if [ $Gx -gt 0 ] && [ $Gy -gt 0 ]; then
	stitchScale=250
	# smooth color
	./TexturePostProcess ToroidalStitch $outDir"/f.png" $outDir"/Stitched_f.png" $stitchScale $stitchScale
	./TexturePostProcess ToroidalStitch $outDir"/fp.png" $outDir"/Stitched_fp.png" $stitchScale $stitchScale

	# tile
	./TexturePostProcess Tile $outDir"/f.png" $outDir"/Tiled_f_blend.png" 250 250 $Gx $Gy 10
	./TexturePostProcess Tile $outDir"/fp.png" $outDir"/Tiled_fp_blend.png" $stitchScale $stitchScale $Gx $Gy 10

	# cleanup
	rm Mesh.png
fi

